@@ -7,6 +7,8 @@ use std::collections::{HashMap, HashSet};
 use std::path::{Path, PathBuf};
 use toml_edit::{value, DocumentMut, Table};
 
+pub use toml_edit;
+
 /// The default maintainer for Rust packages.
 pub const DEFAULT_MAINTAINER: &str =
     "Debian Rust Maintainers <pkg-rust-maintainers@alioth-lists.debian.net>";
@@ -203,7 +205,7 @@ pub struct DebcargoSource<'a> {
     main: &'a mut DebcargoEditor,
 }
 
-impl<'a> DebcargoSource<'a> {
+impl DebcargoSource<'_> {
     /// Return the source section of the debcargo.toml file.
     pub fn toml_section_mut(&mut self) -> &mut Table {
         self.main.debcargo["source"].as_table_mut().unwrap()
@@ -312,16 +314,17 @@ impl<'a> DebcargoSource<'a> {
 
     /// Get the name of the package.
     pub fn name(&self) -> Option<String> {
+        let crate_name = self.main.crate_name()?;
         let semver_suffix = self.main.semver_suffix();
         if semver_suffix {
-            let crate_name = self.main.crate_name().map(debnormalize);
+            let crate_version = self.main.crate_version()?;
             Some(format!(
                 "rust-{}-{}",
-                crate_name?,
-                semver_pair(&self.main.crate_version()?)
+                debnormalize(crate_name),
+                semver_pair(&crate_version)
             ))
         } else {
-            Some(format!("rust-{}", debnormalize(self.main.crate_name()?)))
+            Some(format!("rust-{}", debnormalize(crate_name)))
         }
     }
 
@@ -381,7 +384,12 @@ impl<'a> DebcargoSource<'a> {
             .get("source")
             .and_then(|s| s.get("uploaders"))
             .and_then(|x| x.as_array())
-            .map(|a| a.iter().map(|v| v.as_str().unwrap().to_string()).collect())
+            .map(|a| {
+                a.iter()
+                    .filter_map(|v| v.as_str())
+                    .map(|s| s.to_string())
+                    .collect()
+            })
     }
 
     /// Set the uploaders.
@@ -457,11 +465,11 @@ impl<'a> DebcargoBinary<'a> {
     }
 
     /// Get the package summary.
-    pub fn summary(&self) -> Option<String> {
+    pub fn summary(&self) -> Option<&str> {
         if let Some(summary) = self.table.get("summary").and_then(|v| v.as_str()) {
-            Some(summary.to_string())
+            Some(summary)
         } else {
-            self.global_summary.clone()
+            self.global_summary.as_deref()
         }
     }
 
@@ -470,11 +478,11 @@ impl<'a> DebcargoBinary<'a> {
         if let Some(description) = self.table.get("description").and_then(|v| v.as_str()) {
             Some(description.to_string())
         } else if let Some(description) = self.global_description.as_ref() {
-            Some(description.to_string())
+            Some(description.clone())
         } else {
             match self.key.as_str() {
                 "lib" => Some(format!("Source code for Debianized Rust crate \"{}\"", self.crate_name)),
-                "bin" => Some("This package contains the source for the Rust mio crate, packaged by debcargo for use with cargo and dh-cargo.".to_owned()),
+                "bin" => Some("This package contains the source for the Rust mio crate, packaged by debcargo for use with cargo and dh-cargo.".to_string()),
                 _ => None,
             }
         }
@@ -483,8 +491,8 @@ impl<'a> DebcargoBinary<'a> {
     /// Return the package description.
     pub fn description(&self) -> Option<String> {
         Some(crate::control::format_description(
-            &self.summary()?,
-            self.long_description()?.split('\n').collect(),
+            self.summary()?,
+            self.long_description()?.lines().collect(),
         ))
     }
 
